/** @format */
import Client from '../client/client.js';
import { ClashOfClansBaseClan, ClashOfClansCapitalRaidSeason, ClashOfClansCurrentWar, ClashOfClansLeagueGroup, ClashOfClansLeagueWar, ClashOfClansMember, ClashOfClansModifiedClan, ClashOfClansWarlog } from '../types/ClashOfClans.js';
import BaseGame from './BaseGame.js';
export default class ClashOfClans extends BaseGame {
    readonly players: {
        find: (tag: string) => Promise<unknown>;
    };
    readonly clans: {
        leagueGroup: (tag: string) => Promise<ClashOfClansLeagueGroup>;
        leagueWar: (tag: string) => Promise<ClashOfClansLeagueWar>;
        warlog: (tag: string) => Promise<Array<ClashOfClansWarlog>>;
        find: (name: string) => Promise<Array<ClashOfClansBaseClan>>;
        currentWar: (tag: string) => Promise<ClashOfClansCurrentWar>;
        get: (tag: string) => Promise<ClashOfClansModifiedClan | ClashOfClansBaseClan>;
        members: (tag: string) => Promise<Array<ClashOfClansMember>>;
        capitalRaidSeasons: (tag: string) => Promise<Array<ClashOfClansCapitalRaidSeason>>;
    };
    readonly leagues: {
        capitalLeagues: () => Promise<void>;
        capitalLeague: () => Promise<void>;
        leagues: () => Promise<void>;
        get: () => Promise<void>;
        leagueSeason: () => Promise<void>;
        season: () => Promise<void>;
        warLeague: () => Promise<void>;
        warLeagues: () => Promise<void>;
    };
    readonly rankings: {
        clans: () => Promise<void>;
        players: () => Promise<void>;
        locations: () => Promise<void>;
        location: () => Promise<void>;
    };
    readonly goldpass: {
        current: () => Promise<void>;
    };
    readonly esports: {};
    readonly labels: {
        players: () => Promise<void>;
        clans: () => Promise<void>;
    };
    constructor(client: Client);
    /**
     *  Retrieve information about a clan's current clan war league group.
     * @param {string} tag
     * @returns something
     */
    private leagueGroup;
    /**
     *  Retrieve information about individual clan war league war.
     * @param {string} tag
     * @returns something
     */
    private leagueWar;
    /**
     *  Retrieve clan's clan war log.
     * @param {string} tag
     * @returns something
     */
    private warlog;
    /**
     *  Search clans by name.
     * @param {string} name
     * @returns something
     */
    private find;
    /**
     *  Retrieve information about the clan's current clan war
     * @param {string} tag
     * @returns something
     */
    private currentWar;
    /**
     *  Get clan information
     * @param tag
     * @returns something
     */
    private clan;
    /**
     *  List clan members.
     * @param {string} tag
     * @returns something
     */
    private members;
    /**
     *  Retrieve clan's capital raid seasons
     * @param {string} tag
     * @returns something
     */
    private capitalRaidSeasons;
    /**
     *
     * @param {string} tag
     * @returns something
     */
    private player;
    private capitalLeagues;
    private idk2;
    private leagueSeason;
    private capitalLeague;
    private league;
    private season;
    private warLeague;
    private warLeagues;
    private clanRankings;
    private playerRankings;
    private locations;
    private location;
    private currentSeason;
    private playerLabels;
    private clanLabels;
    /**
     *
     * @param domain
     * @param options
     * @returns
     */
    private cocFetch;
    private modifyClan;
}
